
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: llamazure/azrest:llamazure.rid

from setuptools import setup

setup(**{
    'author': 'Daniel Goldman',
    'classifiers': [
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Topic :: Utilities',
        'Topic :: Internet :: Log Analysis',
    ],
    'description': 'Azure REST client',
    'install_requires': (
        'pydantic>=2.0',
        'requests<3,>=2',
        'types-requests',
    ),
    'license': 'Round Robin 2.0.0',
    'long_description': """# llamazure.azrest : A REST client for the Azure API

Don't use this yet it's not good.
""",
    'long_description_content_type': 'text/markdown',
    'name': 'llamazure.azrest',
    'namespace_packages': (
    ),
    'package_data': {
    },
    'packages': (
        'llamazure',
        'llamazure.azrest',
    ),
    'python_requires': '>=3.8',
    'version': '0.0.2',
})
